@@ -4,6 +4,7 @@ extended datetime module to handle dates related to the GNSS analysis.
 Supports addition of timedelta, subtraction of a datetime.
 
 2014/12/04 Created by Satoshi Kawamoto
+2014/12/09 Added 'gpscal' to the module function.
 
 methods:
     gpscal        : return a tuple (doy, gpsw, gpswd).
@@ -143,11 +144,12 @@ class gnsstime(dt.datetime):
 
     def gpscal(self, *args, date=None, year=None, month=None, day=None, ymd=None):
         """
-        return doy, GPS Week, GPS weekday.
+        return doy, GPS Week (from 1980/1/6), GPS weekday [0:Sunday .. 6:Saturday].
 
-        gpsw = gnsstime.gpsw(date = dt.datetime.utcnow())
-        gpsw = gnsstime.gpsw(year=2013, month=1, day=1)
-        gpsw = gnsstime.gpsw(ymd="2013/01/01")
+        doy, gpsw, gpswd = gnsstime.gpscal(date = dt.datetime.utcnow())
+        doy, gpsw, gpswd = gnsstime.gpscal(year=2013, month=1, day=1)
+        doy, gpsw, gpswd = gnsstime.gpscal(ymd="2013/01/01")
+        doy, gpsw, gpswd = gnsstime.gpscal(2013, 1, 1)
 
         example:
         doy, gpsw, gpswd = gnsstime.gpscal(year=2013, month=1, day=1)
@@ -228,6 +230,9 @@ class gnsstime(dt.datetime):
         elif isinstance(other, dt.timedelta):
             return self + -other
 
+# gpscal for static method
+gpscal = gnsstime(1980, 1, 6).gpscal
+
 def test():
     gt = gnsstime(2011, 1, 1)
     print("--- gpscal test ---")
